@@ -65,7 +65,7 @@ def pulse_volume(ranges, h, theta):
     See :ref:`/notebooks/workflow/recipe1.ipynb`.
 
     """
-    return np.pi * h * (ranges ** 2) * (np.tan(np.radians(theta / 2.0))) ** 2
+    return np.pi * h * (ranges**2) * (np.tan(np.radians(theta / 2.0))) ** 2
 
 
 def beam_block_frac(th, bh, a):
@@ -79,16 +79,16 @@ def beam_block_frac(th, bh, a):
 
     Parameters
     ----------
-    th : float | :class:`numpy:numpy.ndarray` of floats
+    th : float or :class:`numpy:numpy.ndarray`
         Terrain height [m]
-    bh : float | :class:`numpy:numpy.ndarray` of floats
+    bh : float or :class:`numpy:numpy.ndarray`
         Beam height [m]
-    a : float | :class:`numpy:numpy.ndarray` of floats
+    a : float or :class:`numpy:numpy.ndarray`
         Half power beam radius [m]
 
     Returns
     -------
-    pbb : float
+    pbb : float or :class:`numpy:numpy.ndarray`
         Partial beam blockage fraction [unitless]
 
     Examples
@@ -124,7 +124,7 @@ def beam_block_frac(th, bh, a):
     clear = ya < -1.0
     block = ya > 1.0
 
-    numer = (ya * np.sqrt(a ** 2 - y ** 2)) + (a * np.arcsin(ya)) + (np.pi * a / 2.0)
+    numer = (ya * np.sqrt(a**2 - y**2)) + (a * np.arcsin(ya)) + (np.pi * a / 2.0)
 
     denom = np.pi * a
 
