@@ -102,7 +102,7 @@ class CartesianVolume:
         if gridshape is not None:
             warnings.warn(
                 f"``gridshape`` is not used in {self.__class__}. "
-                f"It will be removed in wradlib version 2.0.",
+                "It will be removed in wradlib version 2.0.",
                 DeprecationWarning,
             )
         # radar location in Cartesian coordinates
@@ -352,7 +352,7 @@ def out_of_range(center, gridcoords, maxrange):
         1-D Boolean array of length len(gridcoords)
 
     """
-    return ((gridcoords - center) ** 2).sum(axis=-1) > maxrange ** 2
+    return ((gridcoords - center) ** 2).sum(axis=-1) > maxrange**2
 
 
 def blindspots(center, gridcoords, minelev, maxelev, maxrange):
@@ -382,15 +382,16 @@ def blindspots(center, gridcoords, minelev, maxelev, maxrange):
         tuple of three boolean arrays (below, above, out_of_range) each of length
         (num grid points)
     """
+    site_altitude = center[:, 2]
     # distances of 3-D grid nodes from radar site (center)
     dist_from_rad = np.sqrt(((gridcoords - center) ** 2).sum(axis=-1))
     # below the radar
     below = gridcoords[:, 2] < (
-        georef.bin_altitude(dist_from_rad, minelev, 0, re=6371000) + center[:, 2]
+        georef.bin_altitude(dist_from_rad, minelev, site_altitude, re=6371000)
     )
     # above the radar
     above = gridcoords[:, 2] > (
-        georef.bin_altitude(dist_from_rad, maxelev, 0, re=6371000) + center[:, 2]
+        georef.bin_altitude(dist_from_rad, maxelev, site_altitude, re=6371000)
     )
     # out of range
     out_of_range = dist_from_rad > maxrange
